@@ -1,26 +1,23 @@
-from flask import Blueprint, make_response
+from fastapi import APIRouter, Depends
+from fastapi.responses import PlainTextResponse
 
 from conda_store_server import api
-from conda_store_server.server.utils import get_conda_store
+from conda_store_server.server import dependencies
 
 
-app_metrics = Blueprint("metrics", __name__)
+router_metrics = APIRouter(tags=["metrics"])
 
 
-@app_metrics.route("/metrics")
-def prometheus_metrics():
-    conda_store = get_conda_store()
+@router_metrics.get("/metrics", response_class=PlainTextResponse)
+def prometheus_metrics(
+    conda_store=Depends(dependencies.get_conda_store),
+):
     metrics = api.get_metrics(conda_store.db)
-    response = make_response(
-        "\n".join(f"conda_store_{key} {value}" for key, value in metrics.items())
-    )
-    response.mimetype = "text/plain"
-    return response
+    return "\n".join(f"conda_store_{key} {value}" for key, value in metrics.items())
 
 
-@app_metrics.route("/celery")
-def trigger_task():
-    conda_store = get_conda_store()
+@router_metrics.get("/celery")
+def trigger_task(conda_store=Depends(dependencies.get_conda_store)):
     conda_store.celery_app
 
     def get_celery_worker_status(app):
